Examples
========

Try out in Binder! |Binder|

.. |Binder| image:: https://mybinder.org/badge_logo.svg
    :target: https://mybinder.org/v2/gh/diana-hep/pyhf/master?filepath=docs%2Fexamples%2Fnotebooks%2Fbinderexample%2FStatisticalAnalysis.ipynb

Notebooks:

.. toctree::
   :maxdepth: 2

   examples/notebooks/hello-world.ipynb
   examples/notebooks/binderexample/StatisticalAnalysis.ipynb
   examples/notebooks/XML_ImportExport.ipynb
   examples/notebooks/ShapeFactor.ipynb
   examples/notebooks/multiBinPois.ipynb
   examples/notebooks/multichannel-coupled-histo.ipynb
..
   examples/notebooks/Recast.ipynb
   examples/notebooks/StatError.ipynb
   examples/notebooks/example-tensorflow.ipynb
   examples/notebooks/histogrammar.ipynb
   examples/notebooks/histosys-pytorch.ipynb
   examples/notebooks/histosys.ipynb
   examples/notebooks/importxml.ipynb
   examples/notebooks/multichannel-coupled-normsys.ipynb
   examples/notebooks/multichannel-normsys.ipynb
   examples/notebooks/normsys.ipynb
   examples/notebooks/pytorch_tests_onoff.ipynb
   examples/notebooks/tensorflow-limit.ipynb
